@@ -11,9 +11,7 @@
 #' @return [\code{character}].
 #' @export
 cfReadBrewTemplate = function(template.file) {
-  checkArg(template.file, "character", len=1L, na.ok=FALSE)
-  if (!file.exists(template.file) || isDirectory(template.file))
-    stopf("Template file '%s' not found", template.file)
+  assertFile(template.file, "r")
   tmpl = readLines(template.file)
   if (length(tmpl) == 0L)
     stopf("Error reading template '%s' or empty template", template.file)
@@ -41,10 +39,10 @@ cfReadBrewTemplate = function(template.file) {
 #' @return [\code{character(1)}]. File path of result.
 #' @export
 cfBrewTemplate = function(conf, template, rscript, extension) {
-  checkArg(conf, "environment")
-  checkArg(template, "character", len=1L, na.ok=FALSE)
-  checkArg(rscript, "character", len=1L, na.ok=FALSE)
-  checkArg(extension, "character", len=1L, na.ok=FALSE)
+  assertEnvironment(conf)
+  assertString(template)
+  assertString(rscript)
+  assertString(extension)
   if (conf$debug) {
     # if debug, place in jobs dir
     outfile = sub("\\.R$", sprintf(".%s", extension), rscript)
@@ -53,11 +51,12 @@ cfBrewTemplate = function(conf, template, rscript, extension) {
   }
   pf = parent.frame()
   old = getOption("show.error.messages")
-  on.exit(options(show.error.messages=old))
-  options(show.error.messages=FALSE)
-  z = suppressAll(try(brew(text=template, output=outfile, envir=pf), silent=TRUE))
+  on.exit(options(show.error.messages = old))
+  options(show.error.messages = FALSE)
+  z = suppressAll(try(brew(text = template, output = outfile, envir = pf), silent = TRUE))
   if (is.error(z))
     stopf("Error brewing template: %s", as.character(z))
+  waitForFiles(outfile, conf$fs.timeout)
   return(outfile)
 }
 
@@ -78,13 +77,12 @@ cfBrewTemplate = function(conf, template, rscript, extension) {
 #' @return [\code{\link{SubmitJobResult}}].
 #' @export
 cfHandleUnknownSubmitError = function(cmd, exit.code, output) {
-  checkArg(cmd, "character", len=1L, na.ok=FALSE)
-  exit.code = convertInteger(exit.code)
-  checkArg(exit.code, "integer", len=1L, na.ok=FALSE)
-  checkArg(output, "character", na.ok=FALSE)
+  assertString(cmd)
+  exit.code = asInt(exit.code)
+  assertCharacter(output, any.missing = FALSE)
   msg = sprintf("%s produced exit code %i; output %s",
-    cmd, exit.code, collapse(output, sep="\n"))
-  makeSubmitJobResult(status=101L, batch.job.id=NA_character_, msg=msg)
+    cmd, exit.code, collapse(output, sep = "\n"))
+  makeSubmitJobResult(status = 101L, batch.job.id = NA_character_, msg = msg)
 }
 
 #' Cluster functions helper: Kill a batch job via OS command
@@ -105,18 +103,18 @@ cfHandleUnknownSubmitError = function(cmd, exit.code, output) {
 #'   Default is \code{3}.
 #' @return Nothing.
 #' @export
-cfKillBatchJob = function(cmd, batch.job.id, max.tries=3L) {
-  checkArg(cmd, "character", len=1L, na.ok=FALSE)
-  checkArg(batch.job.id, "character", len=1L, na.ok=FALSE)
-  max.tries = convertInteger(max.tries)
-  checkArg(max.tries, "integer", len=1L, na.ok=FALSE)
+cfKillBatchJob = function(cmd, batch.job.id, max.tries = 3L) {
+  assertString(cmd)
+  assertString(batch.job.id)
+  max.tries = asCount(max.tries)
+  assertCount(max.tries)
 
   for (tmp in seq_len(max.tries)) {
-    res = runOSCommandLinux(cmd, batch.job.id, stop.on.exit.code=FALSE)
+    res = runOSCommandLinux(cmd, batch.job.id, stop.on.exit.code = FALSE)
     if (res$exit.code == 0L)
       return()
     Sys.sleep(1)
   }
   stopf("Really tried to kill job, but could not do it. batch job id is %s.\nMessage: %s",
-        batch.job.id, collapse(res$output, sep="\n"))
+        batch.job.id, collapse(res$output, sep = "\n"))
 }
