@@ -1,5 +1,6 @@
-#' Create cluster functions for SLURM-based systems.
+#' @title Create cluster functions for SLURM-based systems.
 #'
+#' @description
 #' Job files are created based on the brew template
 #' \code{template.file}. This file is processed with brew and then
 #' submitted to the queue using the \code{sbatch} command. Jobs are
@@ -15,25 +16,26 @@
 #' Examples can be found on
 #' \url{https://github.com/tudo-r/BatchJobs/tree/master/examples/cfSLURM}.
 #'
-#' @param template.file [\code{character(1)}]\cr
-#'   Path to a brew template file that is used for the SLURM job file.
-#' @return [\code{\link{ClusterFunctions}}].
+#' @template arg_template
+#' @template arg_list_jobs_cmd
+#' @template ret_cf
 #' @export
-makeClusterFunctionsSLURM = function(template.file) {
+makeClusterFunctionsSLURM = function(template.file, list.jobs.cmd = c("squeue", "-h", "-o %i", "-u $USER")) {
+  assertCharacter(list.jobs.cmd, min.len = 1L, any.missing = FALSE)
   template = cfReadBrewTemplate(template.file)
 
   submitJob = function(conf, reg, job.name, rscript, log.file, job.dir, resources, arrayjobs) {
     outfile = cfBrewTemplate(conf, template, rscript, "sb")
-    res = runOSCommandLinux("sbatch", outfile, stop.on.exit.code=FALSE)
+    res = runOSCommandLinux("sbatch", outfile, stop.on.exit.code = FALSE)
 
     max.jobs.msg = "sbatch: error: Batch job submission failed: Job violates accounting policy (job submit limit, user's size and/or time limits)"
-    output = collapse(res$output, sep="\n")
-    if (grepl(max.jobs.msg, output, fixed=TRUE)) {
-      makeSubmitJobResult(status=1L, batch.job.id=NA_character_, msg=max.jobs.msg)
+    output = collapse(res$output, sep = "\n")
+    if (grepl(max.jobs.msg, output, fixed = TRUE)) {
+      makeSubmitJobResult(status = 1L, batch.job.id = NA_character_, msg = max.jobs.msg)
     } else if (res$exit.code > 0L) {
       cfHandleUnknownSubmitError("sbatch", res$exit.code, res$output)
     } else {
-      makeSubmitJobResult(status=0L, batch.job.id=str_trim(strsplit(output, split=" ")[[1L]][4L]))
+      makeSubmitJobResult(status = 0L, batch.job.id = str_trim(strsplit(output, split = " ")[[1L]][4L]))
     }
   }
 
@@ -43,11 +45,11 @@ makeClusterFunctionsSLURM = function(template.file) {
 
   listJobs = function(conf, reg) {
     # Result is lines of fully quantified batch.job.ids
-    runOSCommandLinux("squeue", "-h -o %i -u $USER")$output
+    runOSCommandLinux(list.jobs.cmd[1L], list.jobs.cmd[-1L])$output
   }
 
   getArrayEnvirName = function() "SLURM_ARRAY_TASK_ID"
 
-  makeClusterFunctions(name="SLURM", submitJob=submitJob, killJob=killJob,
-                       listJobs=listJobs, getArrayEnvirName = getArrayEnvirName)
+  makeClusterFunctions(name = "SLURM", submitJob = submitJob, killJob = killJob,
+                       listJobs = listJobs, getArrayEnvirName = getArrayEnvirName)
 }
