@@ -51,36 +51,36 @@
 #' @export
 #' @examples
 #' # generate results:
-#' reg <- makeRegistry(id="BatchJobsExample", file.dir=tempfile(), seed=123)
-#' f <- function(x) x^2
+#' reg = makeRegistry(id = "BatchJobsExample", file.dir = tempfile(), seed = 123)
+#' f = function(x) x^2
 #' batchMap(reg, f, 1:5)
 #' submitJobs(reg)
 #'
 #' # reduce results to a vector
 #' reduceResultsVector(reg)
 #' # reduce results to sum
-#' reduceResults(reg, fun=function(aggr, job, res) aggr+res)
+#' reduceResults(reg, fun = function(aggr, job, res) aggr+res)
 #'
-#' reg <- makeRegistry(id="BatchJobsExample", file.dir=tempfile(), seed=123)
-#' f <- function(x) list(a=x, b=as.character(2*x), c=x^2)
+#' reg = makeRegistry(id = "BatchJobsExample", file.dir = tempfile(), seed = 123)
+#' f = function(x) list(a = x, b = as.character(2*x), c = x^2)
 #' batchMap(reg, f, 1:5)
 #' submitJobs(reg)
 #'
 #' # reduce results to a vector
-#' reduceResultsVector(reg, fun=function(job, res) res$a)
-#' reduceResultsVector(reg, fun=function(job, res) res$b)
+#' reduceResultsVector(reg, fun = function(job, res) res$a)
+#' reduceResultsVector(reg, fun = function(job, res) res$b)
 #' # reduce results to a list
 #' reduceResultsList(reg)
 #' # reduce results to a matrix
-#' reduceResultsMatrix(reg, fun=function(job, res) res[c(1,3)])
-#' reduceResultsMatrix(reg, fun=function(job, res) c(foo=res$a, bar=res$c), rows=TRUE)
-#' reduceResultsMatrix(reg, fun=function(job, res) c(foo=res$a, bar=res$c), rows=FALSE)
+#' reduceResultsMatrix(reg, fun = function(job, res) res[c(1,3)])
+#' reduceResultsMatrix(reg, fun = function(job, res) c(foo = res$a, bar = res$c), rows = TRUE)
+#' reduceResultsMatrix(reg, fun = function(job, res) c(foo = res$a, bar = res$c), rows = FALSE)
 #' # reduce results to a data.frame
 #' print(str(reduceResultsDataFrame(reg)))
 #' # reduce results to a sum
-#' reduceResults(reg, fun=function(aggr, job, res) aggr+res$a, init=0)
+#' reduceResults(reg, fun = function(aggr, job, res) aggr+res$a, init = 0)
 # FIXME we need more documentation for reduceResultsReturnValue ...
-reduceResults = function(reg, ids, part=NA_character_, fun, init, impute.val, ...) {
+reduceResults = function(reg, ids, part = NA_character_, fun, init, impute.val, ...) {
   checkRegistry(reg)
   syncRegistry(reg)
   if (missing(ids)) {
@@ -95,17 +95,17 @@ reduceResults = function(reg, ids, part=NA_character_, fun, init, impute.val, ..
         stopf("No results available for jobs with ids: %s", collapse(setdiff(ids, done)))
     }
   }
-  checkArg(fun, formals=c("aggr", "job", "res"))
+  assertFunction(fun, c("aggr", "job", "res"))
 
   n = length(ids)
-  message("Reducing ", n, " results...")
+  info("Reducing ", n, " results...")
   if (n == 0L) {
     if (missing(init))
       return(NULL)
     return(init)
   }
 
-  bar = makeProgressBar(max=n, label="reduceResults")
+  bar = makeProgressBar(max = n, label = "reduceResults")
   bar$set()
 
   tryCatch({
@@ -127,13 +127,13 @@ reduceResults = function(reg, ids, part=NA_character_, fun, init, impute.val, ..
                  ...)
       bar$inc(1L)
     }
-  }, error=bar$error)
+  }, error = bar$error)
   return(aggr)
 }
 
 #' @export
 #' @rdname reduceResults
-reduceResultsList = function(reg, ids, part=NA_character_, fun, ..., use.names="ids", impute.val) {
+reduceResultsList = function(reg, ids, part = NA_character_, fun, ..., use.names = "ids", impute.val) {
   checkRegistry(reg)
   syncRegistry(reg)
   if (missing(ids)) {
@@ -151,11 +151,11 @@ reduceResultsList = function(reg, ids, part=NA_character_, fun, ..., use.names="
   if (missing(fun))
     fun = function(job, res) res
   else
-    checkArg(fun, formals=c("job", "res"))
+    assertFunction(fun, c("job", "res"))
   use.names = convertUseNames(use.names)
 
   n = length(ids)
-  messagef("Reducing %i results...", n)
+  info("Reducing %i results...", n)
   if (n == 0L)
     return(list())
   res = vector("list", n)
@@ -166,17 +166,17 @@ reduceResultsList = function(reg, ids, part=NA_character_, fun, ..., use.names="
     it = seq_len(n)
   }
 
-  bar = makeProgressBar(max=n, label="reduceResults")
+  bar = makeProgressBar(max = n, label = "reduceResults")
   bar$set()
   tryCatch({
     for (i in it) {
       # use lazy evaluation!
-      res[[i]] = fun(job = dbGetJobs(reg, ids[i])[[1L]],
-                     res = getResult(reg, ids[i], part),
-                     ...)
+      tmp = fun(job = dbGetJobs(reg, ids[i])[[1L]], res = getResult(reg, ids[i], part), ...)
+      if (!is.null(tmp))
+        res[[i]] = tmp
       bar$inc(1L)
     }
-  }, error=bar$error)
+  }, error = bar$error)
 
   names(res) = switch(use.names,
     "none" = NULL,
@@ -188,16 +188,16 @@ reduceResultsList = function(reg, ids, part=NA_character_, fun, ..., use.names="
 
 #' @export
 #' @rdname reduceResults
-reduceResultsVector = function(reg, ids, part=NA_character_, fun, ..., use.names="ids", impute.val) {
-  unlist(reduceResultsList(reg, ids, part, fun, ..., use.names=use.names, impute.val=impute.val))
+reduceResultsVector = function(reg, ids, part = NA_character_, fun, ..., use.names = "ids", impute.val) {
+  unlist(reduceResultsList(reg, ids, part, fun, ..., use.names = use.names, impute.val = impute.val))
 }
 
 #' @export
 #' @rdname reduceResults
-reduceResultsMatrix = function(reg, ids, part=NA_character_, fun, ..., rows=TRUE, use.names="ids", impute.val) {
-  checkArg(rows, "logical", len=1L, na.ok=FALSE)
+reduceResultsMatrix = function(reg, ids, part = NA_character_, fun, ..., rows = TRUE, use.names = "ids", impute.val) {
+  assertFlag(rows)
   use.names = convertUseNames(use.names)
-  res = reduceResultsList(reg, ids, part, fun, ..., use.names=use.names, impute.val=impute.val)
+  res = reduceResultsList(reg, ids, part, fun, ..., use.names = use.names, impute.val = impute.val)
 
   if (length(res) == 0L)
     return(matrix(0, nrow = 0L, ncol = 0L))
@@ -214,13 +214,13 @@ reduceResultsMatrix = function(reg, ids, part=NA_character_, fun, ..., rows=TRUE
 
 #' @export
 #' @rdname reduceResults
-reduceResultsDataFrame = function(reg, ids, part=NA_character_, fun, ..., use.names="ids", impute.val,
-  strings.as.factors=default.stringsAsFactors()) {
-  checkArg(strings.as.factors, "logical", len=1L, na.ok=FALSE)
+reduceResultsDataFrame = function(reg, ids, part = NA_character_, fun, ..., use.names = "ids", impute.val,
+  strings.as.factors = default.stringsAsFactors()) {
+  assertFlag(strings.as.factors)
 
-  res = reduceResultsList(reg, ids, part, fun, ..., use.names=use.names, impute.val=impute.val)
+  res = reduceResultsList(reg, ids, part, fun, ..., use.names = use.names, impute.val = impute.val)
   if (!length(res))
     return(data.frame())
 
-  list2df(res, force.names=TRUE, strings.as.factors = strings.as.factors)
+  list2df(res, force.names = TRUE, strings.as.factors = strings.as.factors)
 }
