@@ -1,22 +1,23 @@
 writeRscripts = function(reg, cf, ids, chunks.as.arrayjobs, resources.timestamp, disable.mail, delays) {
+  # force loading 'methods' on slave to avoid package trouble there for some jobs
   template = paste(
     "Sys.sleep(%%f)",
-    "options(BatchJobs.on.slave=TRUE, BatchJobs.resources.path='%s')",
+    "options(BatchJobs.on.slave = TRUE, BatchJobs.resources.path = '%s')",
     "library(BatchJobs)",
     "res = BatchJobs:::doJob(",
-    "\treg=loadRegistry('%s'),",
-    "\tids=c(%%s),",
-    "\tmultiple.result.files=%s,",
-    "\tdisable.mail=%s,",
-    "\tfirst=%iL,",
-    "\tlast=%iL,",
-    "\tarray.id=%s)",
+    "\treg = loadRegistry('%s'),",
+    "\tids = c(%%s),",
+    "\tmultiple.result.files = %s,",
+    "\tdisable.mail = %s,",
+    "\tfirst = %iL,",
+    "\tlast = %iL,",
+    "\tarray.id = %s)",
     "BatchJobs:::setOnSlave(FALSE)",
-    sep="\n")
-  fids = vapply(ids, head, integer(1L), 1L) # first job id in chunk
+    sep = "\n")
+  fids = viapply(ids, head, 1L) # first job id in chunk
   first = head(fids, 1L)
   last = tail(fids, 1L)
-  ids = vapply(ids, function(id) collapse(paste0(id, "L")), character(1L)) # ids as collapsed strings
+  ids = vcapply(ids, function(id) collapse(paste0(id, "L"))) # ids as collapsed strings
 
   # print the constant arguments (of length 1) into the template
   resources.path = getResourcesFilePath(reg, resources.timestamp)
@@ -25,7 +26,8 @@ writeRscripts = function(reg, cf, ids, chunks.as.arrayjobs, resources.timestamp,
 
   # print delays and ids into template. sprintf will return a string of length length(delays) == length(ids)
   # put this together with file names into an mapply on cat.
-  mapply(FUN=cat, SIMPLIFY=FALSE, USE.NAMES=FALSE,
-         sprintf(template, delays, ids),
-         file = getRScriptFilePath(fids, reg = reg))
+  files = getRScriptFilePath(fids, reg = reg)
+  mapply(FUN = cat, SIMPLIFY = FALSE, USE.NAMES = FALSE,
+    sprintf(template, delays, ids), file = files)
+  invisible(files)
 }
